@@ -1,11 +1,4 @@
 class Button:
-    button_id: int
-    enabled: bool
-    name: str
-    agent_only: bool
-    require_comment: bool
-    colour: str
-
     def __init__(
         self,
         button_id: str,
