@@ -1,19 +1,15 @@
-class User:
-    user_id: str
-    title: str
-    job_title: str
-    first_name: str
-    last_name: str
-    email: str
+from typing import Optional
 
+class User:
     def __init__(
         self,
-        user_id: str,
-        first_name: str,
-        last_name: str,
-        email: str,
-        title: str = None,
-        job_title: str = None,
+        user_id: int,
+        first_name: Optional[str],
+        last_name: Optional[str],
+        email: Optional[str],
+        title: Optional[str] = None,
+        job_title: Optional[str] = None,
+        resource_owner_id: Optional[int] = None,
     ):
         self.user_id = user_id
         self.first_name = first_name
@@ -22,6 +18,7 @@ class User:
 
         self.title = title
         self.job_title = job_title
+        self.resource_owner_id = resource_owner_id
 
     def get_name(self):
         return self.first_name + " " + self.last_name
@@ -40,6 +37,7 @@ class User:
             data["email"],
             data["title"],
             data["job_title"],
+            data["number"]
         )
         return user_obj
 
