@@ -58,6 +58,8 @@ def test_create_ticket():
     ticket = cc.create_ticket(
         subject=subj,
         description=desc,
+        account_vp=1,
+        customer_user_vp=1,
         project_id=8,
         workspace_id=141,
         type_id=8,
@@ -336,6 +338,11 @@ def test_add_user_watcher():
     ticket.refresh()
     assert len(ticket.user_watchers) == 1
 
+    # Test adding an email watcher
+    # ticket.add_user_watcher_by_email("test@example.com")
+    # ticket.refresh()
+    # assert ticket.user_watchers[1].email == "test@example.com"
+
 
 def test_assignee_user_by_id():
     ticket = cc.get_ticket_by_id(pytest.ticket_id)
@@ -353,12 +360,14 @@ def test_create_related_ticket():
     ticket = cc.create_ticket(
         subject=subj,
         description=desc,
+        account_vp=1,
+        customer_user_vp=1,
         project_id=8,
         type_id=8,
         workspace_id=141,
         priority=33,
         custom_fields_attributes=[{"id": 17, "values": 0}, {"id": 75, "values": 363}],
-        related_tickets=[pytest.ticket_id],
+        related_tickets=[int(pytest.ticket_id)],
     )
     ticket.refresh()
 
@@ -370,6 +379,7 @@ def test_create_related_ticket():
     # assert ticket.sid == sid
     assert ticket.custom_fields["ms_category"]["id"] == 363
     assert ticket.owner.user_id == 14012  # Thomas Scholtz
+    assert ticket.owner.resource_owner_id == 13962 # Thomas Scholtz
     assert ticket.creator.user_id == 14012  # Thomas Scholtz
     assert ticket.status.status_id == 1  # New
     assert ticket.status.name == "New"
@@ -401,6 +411,9 @@ def test_create_related_ticket():
     ticket.related_tickets.append(pytest.ticket_id)
     ticket.commit()
 
+    # When adding a ticket as related and then commenting on the ticket, sometimes the related ticket is removed from the related_tickets list.
+    ticket.commit(comment="This is a comment")
+
     orig_ticket.refresh()
     ticket.refresh()
     assert len(orig_ticket.related_tickets) == 1
@@ -408,15 +421,17 @@ def test_create_related_ticket():
     assert orig_ticket.related_tickets[0] == int(ticket.ticket_id)
 
 
+
 def test_internal_event():
     subj = "[Test-Ticket]"
     desc = "<h1>This is a related test ticket. Please ignore</h1>"
     # sid = "ZZZ"
 
     ticket = cc.create_ticket(
-        account_vp=1631,
         subject=subj,
         description=desc,
+        account_vp=1,
+        customer_user_vp=1,
         project_id=8,
         type_id=8,
         workspace_id=141,
@@ -449,7 +464,8 @@ def test_internal_event_ticket_not_visible():
 
     ticket = cc.create_ticket(
         assignee="User:14012",
-        account_vp=1631,
+        account_vp=1,
+        customer_user_vp=1,
         subject=subj,
         description=desc,
         project_id=8,
@@ -529,6 +545,8 @@ def test_ensure_multiple_tickets_dont_use_same_attributes():
     ticket = cc.create_ticket(
         subject=subj,
         description=desc,
+        account_vp=1,
+        customer_user_vp=1,
         project_id=8,
         workspace_id=141,
         type_id=8,
@@ -565,6 +583,8 @@ def test_ensure_multiple_tickets_dont_use_same_attributes():
     ticket2 = cc.create_ticket(
         subject=subj,
         description=desc,
+        account_vp=1,
+        customer_user_vp=1,
         project_id=8,
         workspace_id=141,
         type_id=8,
